%define name	mailman
%define version 2.0.13
%define release 3mdk

Summary:	The GNU Mailing List Management System
Name:		%{name}
Version:	%{version}
Release:	%{release}
Group:		System/Servers
License:	GPL
URL:		http://www.list.org/
Source:		ftp://ftp.gnu.org/gnu/mailman/%{name}-%{version}.tar.bz2
Patch0:		mailman-buildroot-check.patch.bz2
Patch1:		mailman-2.0.13-apache-conf.patch.bz2
Patch2:		mailman-2.0.13-cgi-group.patch.bz2
Patch3:		mailman-2.0.13-destdir.patch.bz2
BuildRoot:	%{_tmppath}/%{name}-buildroot
BuildRequires:	perl
Prereq:		python >= 1.5.2
Requires:	webserver smtpdaemon

%define prefixdir %{_localstatedir}/%{name}
%define apacheroot %{_var}/www
%define apachebase %{_sysconfdir}/httpd

%description
Mailman -- The GNU Mailing List Management System --
is a mailing list management system written mostly in
Python. Features:

  o Most standard mailing list features, including:
     moderation, mail based commands, digests, etc...
  o An extensive Web interface, customizable on a per-list basis.
  o Web based list administration interface for *all* admin-type tasks
  o Automatic Web based hypermail-style archives (using pipermail or
    other external archiver), including provisions for private archives
  o Integrated mail list to newsgroup gatewaying
  o Integrated newsgroup to mail list gatewaying (polling-based... if you
     have access to the nntp server, you should be able to easily do
     non-polling based news->mail list gatewaying; email viega@list.org,
     I'd like to help get that going and come up
     with instructions)
  o Smart bounce detection and correction
  o Integrated fast bulk mailing
  o Smart spam protection
  o Extensible logging
  o Multiple list owners and moderators are possible
  o Optional MIME-compliant digests
  o Nice about which machine you subscribed from if you're from the
        right domain

%prep
%setup -q
%patch0 -p1 -b .buildroot
%patch1 -p1 -b .apache-conf
%patch2 -p1 -b .cgi-group
%patch3 -p1 -b .destdir

%build
mkdir -p %{buildroot}%{prefixdir}

# As a normal user, we don't have permissions to do this.  %patch0 changes
#   configure so that the directory check will never fail.
#chown %{username}.%{groupname} %{buildroot}%{prefixdir}
#chmod 02775 %{buildroot}%{prefixdir}
MAILHOST=localhost.localdomain
WWWHOST=localhost.localdomain
export MAILHOST
export WWWHOST
./configure --with-mail-gid=nogroup --with-cgi-gid=apache --with-username=mail --with-groupname=mail --prefix=%{prefixdir}

%make

%install
[ -n "%{buildroot}" -a "%{buildroot}" != / ] && rm -rf %{buildroot}

make DESTDIR=%{buildroot} var_prefix=%{prefixdir} prefix=%{prefixdir} install

mkdir -p %{buildroot}%{apacheroot}/icons
cp misc/mailman.jpg %{buildroot}%{apacheroot}/icons/
cp misc/PythonPowered.png %{buildroot}%{apacheroot}/icons/
cp misc/gnu-head-tiny.jpg %{buildroot}%{apacheroot}/icons/
mkdir -p %{buildroot}%{apachebase}/conf
cp mailman.conf %{buildroot}%{apachebase}/conf/

# Generate a list of all files but mm_cfg.py in {prefix}/Mailman/ to be
# used in files section below (mm_cfg.py is a configuration file)
find %{buildroot}%{prefixdir}/Mailman -name *.py >Mailman.list
perl -pi -e "s|^%{buildroot}||g;" Mailman.list
perl -pi -e "s|^%{prefixdir}/Mailman/mm_cfg.py||g;" Mailman.list

# cleanup
rm -f %{buildroot}%{prefixdir}/Mailman/mm_cfg.py.dist

%post
cd %{prefixdir}
bin/update | tee ./updates.log > /dev/null
bin/check_perms -f > /dev/null
if [ $1 = 1 ]; then
  if [ -f %{apachebase}/conf/httpd.conf ]; then
    echo 'Include conf/%{name}.conf' >> %{apachebase}/conf/httpd.conf
  fi
  if [ -f %{_sysconfdir}/postfix/aliases ]; then
    if [ `grep -c mailman %{_sysconfdir}/postfix/aliases` = 0 ]; then
      echo '' >> %{_sysconfdir}/postfix/aliases
      echo '# Added by the %{name} rpm' >> %{_sysconfdir}/postfix/aliases
      echo 'mailman:	root' >> %{_sysconfdir}/postfix/aliases
      echo 'mailman-owner:	mailman' >> %{_sysconfdir}/postfix/aliases
      newaliases
    fi
  fi
  crontab -u mail %{prefixdir}/cron/crontab.in
  echo ''
  echo '*****'
  echo '* You must now "cd %{prefixdir}/" and run "bin/mmsitepass" as root to set the'
  echo '* site password to be used for administrating all Mailman data as necessary.'
  echo '*****'
  echo ''
  %{_initrddir}/httpd update
fi
# we have to do the compilation post install otherwise buildroot is always
# embedded in the binaries
echo "Post-install compilation..."
%{_bindir}/python -c 'from compileall import *; compile_dir("%{prefixdir}/Mailman")' >/dev/null

%preun
if [ $1 = 0 ]; then
  # since we compile pyc files during %post, we need to remove them here on uninstall
  find %{prefixdir}/Mailman -name *.pyc -exec rm -f {} \;
  rm -f %{prefixdir}/{bin,cron}/paths.pyc
fi

%postun
if [ $1 = 0 ]; then
  if [ -f %{apachebase}/conf/httpd.conf ]; then
    if [ -x %{__perl} ]; then
      perl -pi -e "s|Include conf/%{name}.conf\n||g;" %{apachebase}/conf/httpd.conf
      %{_initrddir}/httpd update
    fi
  fi
  if [ -f %{_sysconfdir}/postfix/aliases ]; then
    if [ `grep -c mailman %{_sysconfdir}/postfix/aliases` != 0 ]; then
      if [ -x %{__perl} ]; then
        perl -pi -e "s|# Added by the %{name} rpm\n||g;" %{_sysconfdir}/postfix/aliases
        perl -pi -e "s|mailman:	root\n||g;" %{_sysconfdir}/postfix/aliases
        perl -pi -e "s|mailman-owner:	mailman\n||g;" %{_sysconfdir}/postfix/aliases
        newaliases
      fi
    fi
  fi
  crontab -u mail -r
fi


%clean
[ -n "%{buildroot}" -a "%{buildroot}" != / ] && rm -rf %{buildroot}

%files -f Mailman.list
%defattr(-,mail,mail)
%attr(-,root,root) %doc ACKNOWLEDGMENTS BUGS FAQ INSTALL NEWS README TODO UPGRADING
%attr(-,root,root) %doc README.BSD README.EXIM README.LINUX README.NETSCAPE README.QMAIL README.SENDMAIL
%attr(-,root,root) %doc gnu-COPYING-GPL
%attr(02775,mail,mail) %dir %{prefixdir}
%dir %{prefixdir}/archives
%dir %{prefixdir}/archives/private
%dir %{prefixdir}/archives/public
%dir %{prefixdir}/bin
%dir %{prefixdir}/cgi-bin
%dir %{prefixdir}/cron
%dir %{prefixdir}/data
%dir %{prefixdir}/filters
%dir %{prefixdir}/icons
%dir %{prefixdir}/lists
%dir %{prefixdir}/locks
%dir %{prefixdir}/logs
%dir %{prefixdir}/mail
%dir %{prefixdir}/Mailman
%dir %{prefixdir}/Mailman/Archiver
%dir %{prefixdir}/Mailman/Bouncers
%dir %{prefixdir}/Mailman/Cgi
%dir %{prefixdir}/Mailman/Handlers
%dir %{prefixdir}/Mailman/Logging
%dir %{prefixdir}/Mailman/pythonlib
%dir %{prefixdir}/qfiles
%dir %{prefixdir}/scripts
%dir %{prefixdir}/spam
%dir %{prefixdir}/templates
%{prefixdir}/bin/*
%attr(02755,mail,mail) %{prefixdir}/cgi-bin/*
%{prefixdir}/cron/*
%config(noreplace) %{prefixdir}/data/pending_subscriptions.db
%{prefixdir}/filters/*
%{prefixdir}/icons/*
%{prefixdir}/mail/*
%{prefixdir}/scripts/*
%{prefixdir}/templates/*
%attr(-,root,root) %{apacheroot}/icons/*
%config(noreplace) %{prefixdir}/Mailman/mm_cfg.py
%attr(-,root,root) %config(noreplace) %{apachebase}/conf/mailman.conf

%changelog
* Fri Nov 29 2002 Vincent Danen <vdanen@mandrakesoft.com> 2.0.13-3mdk
- P3 to use DESTDIR instead of passing %%{buildroot} to prefix/var_prefix
- compile Mailman python modules in %%post; this seems to be the only way we
  can strip the buildroot out of the compiled pyc files
- force removal of *.pyc files in %%preun if we are removing the package
  (can't be in %%postun or rpm leaves empty directories behind)
- cleanup file list
- change location of file list (not in buildroot)
- remove unpackaged files (grrr)

* Tue Sep 17 2002 Frederic Lepied <flepied@mandrakesoft.com> 2.0.13-2mdk
- fixed apache config (patch1)
- use a group name instead of an id in cgi-wrapper.c (patch2)

* Fri Aug 23 2002 Vincent Danen <vdanen@mandrakesoft.com> 2.0.13-1mdk
- 2.0.13

* Tue Jul 16 2002 Vincent Danen <vdanen@mandrakesoft.com> 2.0.12-1mdk
- 2.0.12 (more cross-site scripting vulnerabilities)

* Thu May 23 2002 Yves Duret <yduret@mandrakesoft.com> 2.0.11-1mdk
- version 2.0.11 (fix cross-site vulnerabilites).

* Tue Apr 30 2002 Yves Duret <yduret@mandrakesoft.com> 2.0.10-1mdk
- version 2.0.10 (mainly security updates).

* Tue Apr 30 2002 Yves Duret <yduret@mandrakesoft.com> 2.0.7-2mdk
- use gid nogroup instead of depreciated nobody
  mailman should now works again.

* Thu Nov 15 2001 Lenny Cartier <lenny@mandrakesoft.com> 2.0.7-1mdk
- 2.0.7

* Mon Sep 12 2001 Lenny Cartier <lenny@mandrakesoft.com> 2.0.6-1mdk
- updated by Paul Cox <pcox@linux-mandrake.com> :
	- 2.0.6 (finally!)
	- More secure apache config (in mailman.conf), just in case of insane global
  	settings.

* Fri Jun 01 2001 Paul Cox <pcox@linux-mandrake.com> 2.0.5-3mdk
- Moved Mailman to /var/lib/mailman to be more compliant with FHS.  (See
  archive of mdk-admin at http://freezer-burn.org/archives/mdk-admin/
  if you have questions about this.)
- Changed --with-mail-gid and --with-cgi-gid to user names instead of user
  numbers in case they ever change.
- Changed --with-mail-gid=nobody as that's how Postfix is setup by default
  (see default_privs in Postfix's main.cf).
- Fixed upgrades (will not overwrite config files, etc.), and tweaked files
  section (added a 'BuildRequires: perl' as a result).
- Made sure that bin/update runs in order to update any existing lists.
- Fixed permissions.  Mailman will try to fix its permissions on install.
- Added mailman.conf for apache configuration (included into httpd.conf).
- Install will now attempt to add the required aliases (Postfix only).
- Removed mailman user addition (Mailman requires that whatever user and
  group is passed to the configure script to be the userid and groupid, so
  since we did --with-username=mail and --with-groupname=mail (so that we
  don't have to be root to build), creating a mailman user was not necessary).
- Fixed crontab.in import.  Not in the right format to be simply put in
  /etc/cron.d, so we have to use crontab to import it (as user mail).
- Removed obsolete LEIAME patch.
- Changed URL back to the much nicer www.list.org mirror.
- Lots and lots of macroization and countless other .spec file changes.

* Wed May 16 2001 Vincent Danen <vdanen@mandrakesoft.com> 2.0.5-2mdk
- apache runs as gid 48 now, so change --with-cgi-gid from 99 to 48

* Tue May  8 2001 Guillaume Cottenceau <gc@mandrakesoft.com> 2.0.5-1mdk
- version 2.0.5

* Tue Mar 06 2001 Lenny Cartier <lenny@mandrakesoft.com> 2.0.2-1mdk
- updated to 2.0.2

* Fri Jan 19 2001 Vincent Danen <vdanen@mandrakesoft.com> 2.0.1-1mdk
- 2.0.1
- fix url
- move /home/httpd to /var/www

* Mon Dec 11 2000 Lenny Cartier <lenny@mandrakesoft.com> 2.0-1mdk
- change user
- used srpm from Stefane Fermigier <sf@fermigier.com>

* Mon Jun 05 2000 Andreas Hasenack <andreas@conectiva.com>
- now requires smtpdaemon instead of sendmail

* Fri May 26 2000 Eliphas Levy Theodoro <eliphas@conectiva.com>
- added macros and removed warning-things for the testing environment
- added patch to configure so now he don't complain with maildir directory
- changed attribute of maildir directory to 02775 in %files

* Thu May 25 2000 Gustavo Niemeyer <niemeyer@conectiva.com>
- Updated to 2.0beta2
- Updated images

* Mon May 15 2000 Elvis Pftzenreuter <epx@conectiva.com>
- using stackguard compiler
- allows non-root compilation

* Wed Sep 15 1999 Rud Moura <ruda@conectiva.com>
- First build for Conectiva
- Adopted by Conectiva Linux
